==> haskell-zinza-0.2-273-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zinza
version:              0.2
visibility:           public
id:                   zinza-0.2-HQZdvzFCovJF3KIHeX5lCP
key:                  zinza-0.2-HQZdvzFCovJF3KIHeX5lCP
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  666e2221be9de791758f4366e732878c
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/zinza-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/zinza-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/zinza-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zinza
hs-libraries:         HSzinza-0.2-HQZdvzFCovJF3KIHeX5lCP
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zinza-0.2-274-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zinza.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 zinza
version:              0.2
visibility:           public
id:                   zinza-0.2-68l5PtrikoqJabOD8tdX4W
key:                  zinza-0.2-68l5PtrikoqJabOD8tdX4W
license:              GPL-2.0-or-later
copyright:            (c) 2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg.Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/zinza
synopsis:             Typed templates with jinja like syntax
description:
    Typed templates with jinja like syntax. Well-typed templates don'\''t go wrong.

category:             Text, Template
abi:                  192bb4d516b9711c78a3d9dd2af61f6a
exposed:              True
exposed-modules:      Zinza
hidden-modules:
    Zinza.Check Zinza.Class Zinza.Errors Zinza.Expr Zinza.Generic
    Zinza.Indexing Zinza.Module Zinza.Node Zinza.Parser Zinza.Pos
    Zinza.Type Zinza.Value Zinza.Var Zinza.Writer

import-dirs:          /usr/lib/ghc-9.4.8/site-local/zinza-0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/zinza-0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/zinza-0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zinza
hs-libraries:         HSzinza-0.2-68l5PtrikoqJabOD8tdX4W
depends:
    base-4.17.2.1 containers-0.6.7 parsec-3.1.16.1 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-zinza/html/zinza.haddock
haddock-html:         /usr/share/doc/haskell-zinza/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
